==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/RadialGaugeRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RadialGaugeRangeDescription } from "./RadialGaugeRangeDescription";
/**
 * @hidden
 */
var RadialGaugeRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialGaugeRangeDescriptionMetadata, _super);
    function RadialGaugeRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RadialGaugeRangeDescriptionMetadata.b = function (a) {
        if (RadialGaugeRangeDescriptionMetadata.a == null) {
            RadialGaugeRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialGaugeRangeDescriptionMetadata.c(RadialGaugeRangeDescriptionMetadata.a);
        }
        if (a.k(RadialGaugeRangeDescriptionMetadata.a)) {
            return;
        }
        a.ab(RadialGaugeRangeDescriptionMetadata.a);
    };
    RadialGaugeRangeDescriptionMetadata.c = function (a) {
        a.item("Name", "String");
        a.item("Brush", "Brush");
        a.item("Outline", "Brush");
        a.item("StartValue", "Number:double");
        a.item("EndValue", "Number:double");
        a.item("InnerStartExtent", "Number:double");
        a.item("InnerEndExtent", "Number:double");
        a.item("OuterStartExtent", "Number:double");
        a.item("OuterEndExtent", "Number:double");
        a.item("StrokeThickness", "Number:double");
    };
    RadialGaugeRangeDescriptionMetadata.d = function (a) {
        RadialGaugeRangeDescriptionMetadata.b(a);
        a.ad("RadialGaugeRange", function () { return new RadialGaugeRangeDescription(); });
        a.ac("RadialGaugeRange", RadialGaugeRangeDescriptionMetadata.a);
    };
    RadialGaugeRangeDescriptionMetadata.$t = markType(RadialGaugeRangeDescriptionMetadata, 'RadialGaugeRangeDescriptionMetadata');
    RadialGaugeRangeDescriptionMetadata.a = null;
    return RadialGaugeRangeDescriptionMetadata;
}(Base));
export { RadialGaugeRangeDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/RadialGaugeRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RadialGaugeRangeDescription } from "./RadialGaugeRangeDescription";
/**
 * @hidden
 */
var RadialGaugeRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialGaugeRangeDescriptionMetadata, _super);
    function RadialGaugeRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RadialGaugeRangeDescriptionMetadata.b = function (a) {
        if (RadialGaugeRangeDescriptionMetadata.a == null) {
            RadialGaugeRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialGaugeRangeDescriptionMetadata.c(RadialGaugeRangeDescriptionMetadata.a);
        }
        if (a.k(RadialGaugeRangeDescriptionMetadata.a)) {
            return;
        }
        a.ac(RadialGaugeRangeDescriptionMetadata.a);
    };
    RadialGaugeRangeDescriptionMetadata.c = function (a) {
        a.item("Name", "String");
        a.item("Brush", "Brush");
        a.item("Outline", "Brush");
        a.item("StartValue", "Number:double");
        a.item("EndValue", "Number:double");
        a.item("InnerStartExtent", "Number:double");
        a.item("InnerEndExtent", "Number:double");
        a.item("OuterStartExtent", "Number:double");
        a.item("OuterEndExtent", "Number:double");
        a.item("StrokeThickness", "Number:double");
    };
    RadialGaugeRangeDescriptionMetadata.d = function (a) {
        RadialGaugeRangeDescriptionMetadata.b(a);
        a.ae("RadialGaugeRange", function () { return new RadialGaugeRangeDescription(); });
        a.ad("RadialGaugeRange", RadialGaugeRangeDescriptionMetadata.a);
    };
    RadialGaugeRangeDescriptionMetadata.$t = markType(RadialGaugeRangeDescriptionMetadata, 'RadialGaugeRangeDescriptionMetadata');
    RadialGaugeRangeDescriptionMetadata.a = null;
    return RadialGaugeRangeDescriptionMetadata;
}(Base));
export { RadialGaugeRangeDescriptionMetadata };
